@@ -10,6 +10,10 @@ use Fatal qw(open close unlink);
 use Data::Dumper;
 use File::Glob qw(bsd_glob);
 use Carp;
+use lib '.';
+
+# Ensure deterministic output
+$Data::Dumper::Sortkeys = 1;
 
 # use the system version of a module if present; in theory this could lead to
 # compatibility problems (if the latest version of one of the dependencies,
@@ -316,7 +320,7 @@ sub extract_wxwidgets {
     print "Extracting wxWidgets...\n";
 
     $self->_load_bundled_modules;
-    $Archive::Extract::PREFER_BIN = 1;
+    $Archive::Extract::PREFER_BIN = ( $^O =~ /^mswin/i ) ? 0 : 1;
     my $ae = Archive::Extract->new( archive => $archive );
 
     die 'Error: ', $ae->error unless $ae->extract;
